##  Enter the Copied Credentials in SAP LeanIX
  1. Add the WalkMe integration in SAP LeanIX. For a detailed guide, see [Setting Up Out-of-the-Box Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ba7437a441014af4ea67e4bf11105__setting_up_out-of-the-box_integrations).
  2. In the configuration, give a name for the integration and select the type of capabilities or data you want to get from WalkMe. SaaS Discovery is enabled by default, and you can optionally enable or disable Usage Indication.
  3. Enter the credentials copied from the WalkMe Admin Center into the corresponding fields:
     * API URL: Enter the API URL based on your WalkMe account's region. For details, refer to the [WalkMe documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.walkme.com%2Freference%2Fgetting-started-with-your-api%23api-base-url "https://developer.walkme.com/reference/getting-started-with-your-api#api-base-url").
     * Client ID and Client Secret: Enter the client ID and secret obtained when creating an API key.
![Entering the Required Credentials in SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741d2dc7a4410149223dbf4d7a2318c_LowRes.png)
Entering the Required Credentials in SAP LeanIX
  4. Click Finish and wait for the connection to be established.
